@@ -180,12 +180,15 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
     font.setPointSize(15);
     p->setFont(font);
     const int dayLabelsHeight = 20;
+    const auto dayInMonth = mMonthView->averageDate();
     p->drawText(QRect(0,
                       0, // top right
                       static_cast<int>(mScene->sceneRect().width()),
                       static_cast<int>(mScene->headerHeight() - dayLabelsHeight)),
                 Qt::AlignCenter,
-                mMonthView->averageDate().toString(QStringLiteral("MMMM yyyy")));
+                i18nc("monthname year", "%1 %2",
+                    QLocale().standaloneMonthName(dayInMonth.month(), QLocale::LongFormat),
+                    QString::number(dayInMonth.year())));
 
     font.setPointSize(dayLabelsHeight - 10);
     p->setFont(font);
@@ -212,7 +215,7 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
     */
     int columnWidth = mScene->columnWidth();
     int rowHeight = mScene->rowHeight();
-    QDate todayDate {QDate::currentDate()};
+    QDate todayDate{QDate::currentDate()};
 
     const QList<QDate> workDays = CalendarSupport::workDays(mMonthView->actualStartDateTime().date(), mMonthView->actualEndDateTime().date());
     QRect todayRect;
@@ -518,8 +521,6 @@ void MonthScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
 
     // If an item was selected during the click, we maybe have an item to move !
     if (mActionItem) {
-        MonthCell *currentCell = getCellFromPos(pos);
-
         // Initiate action if not already done
         if (!mActionInitiated && mActionType != None) {
             if (mActionType == Move) {
@@ -532,18 +533,29 @@ void MonthScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
         view->setActionCursor(mActionType);
 
         // Move or resize action
-        if (currentCell && currentCell != mPreviousCell) {
+        MonthCell * const currentCell = getCellFromPos(pos);
+        if (currentCell != mPreviousCell) {
             bool ok = true;
             if (mActionType == Move) {
-                mActionItem->moveBy(mPreviousCell->date().daysTo(currentCell->date()));
+                if (currentCell) {
+                    mActionItem->moveTo(currentCell->date());
+                    mActionItem->updateGeometry();
+                } else {
+                    mActionItem->moveTo(QDate());
+                    mActionItem->updateGeometry();
+                    mActionItem->endMove();
+                    mActionItem = nullptr;
+                    mActionType = None;
+                    mStartCell = nullptr;
+                }
             } else if (mActionType == Resize) {
                 ok = mActionItem->resizeBy(mPreviousCell->date().daysTo(currentCell->date()));
+                mActionItem->updateGeometry();
             }
 
             if (ok) {
                 mPreviousCell = currentCell;
             }
-            mActionItem->updateGeometry();
             update();
         }
         mouseEvent->accept();
